aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorTomáš Jusko2022-12-04 20:55:55 +0100
committerTomáš Jusko2022-12-04 20:55:55 +0100
commit3c6ae5d039182da2a4078fa27d1220eb47268799 (patch)
treeef1a9a8728599b88c7cd2961bf4a9553b6449c28
parent2a5e63f5bf0f362b2936b89ea686795d3827053d (diff)
downloadpyecsca-3c6ae5d039182da2a4078fa27d1220eb47268799.tar.gz
pyecsca-3c6ae5d039182da2a4078fa27d1220eb47268799.tar.zst
pyecsca-3c6ae5d039182da2a4078fa27d1220eb47268799.zip
fix: Fixed chipwhisperer imports
-rw-r--r--pyecsca/sca/target/chipwhisperer.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/pyecsca/sca/target/chipwhisperer.py b/pyecsca/sca/target/chipwhisperer.py
index c9380cc..47e3ab0 100644
--- a/pyecsca/sca/target/chipwhisperer.py
+++ b/pyecsca/sca/target/chipwhisperer.py
@@ -8,8 +8,8 @@ using ChipWhisperer-Lite or Pro.
from time import sleep
import chipwhisperer as cw
-from chipwhisperer.capture.scopes.base import ScopeTemplate
-from chipwhisperer.capture.targets import SimpleSerial
+from chipwhisperer.capture.scopes import ScopeTypes
+from chipwhisperer.capture.targets.SimpleSerial import SimpleSerial
from public import public
from .flash import Flashable
@@ -21,7 +21,7 @@ class ChipWhispererTarget(Flashable, SimpleSerialTarget): # pragma: no cover
"""ChipWhisperer-based target, using the SimpleSerial protocol and communicating using ChipWhisperer-Lite/Pro."""
def __init__(
self, target: SimpleSerial, scope: ScopeTemplate, programmer, **kwargs
):
super().__init__()
self.target = target
@@ -21,7 +21,7 @@ class ChipWhispererTarget(Flashable, SimpleSerialTarget): # pragma: no cover
"""ChipWhisperer-based target, using the SimpleSerial protocol and communicating using ChipWhisperer-Lite/Pro."""
def __init__(
- self, target: SimpleSerial, scope: ScopeTemplate, programmer, **kwargs
+ self, target: SimpleSerial, scope: ScopeTypes, programmer, **kwargs
):
super().__init__()